@@ -5,7 +5,7 @@ package IO::ReadPreProcess;
 # It provides IO::Handle-ish functions to slot in easily to most scripts.
 
 # Author: Alain D D Williams <addw@phcomp.co.uk> March 2015, 2016, 2017 Copyright (C) the author.
-# SCCS: @(#)ReadPreProcess.pm	1.11 06/03/17 13:53:05
+# SCCS: @(#)ReadPreProcess.pm	1.12 06/03/17 16:59:37
 
 use 5.006;
 use strict;
@@ -18,7 +18,7 @@ our $errstr; # Error string
 
 use Math::Expression;
 
-our $VERSION = 0.82;
+our $VERSION = 0.83;
 
 # Control directive recognised by getline():
 my %ctlDirectives = map { $_ => 1 } qw/ break case close continue do done echo else elseif elsif endswitch error eval exit
@@ -2194,9 +2194,9 @@ The variables that are set can be used to control what it reads.
         my $inc = IO::ReadPreProcess->new(File => $file, Math => $ArithEnv, OnError => 'die', PipeOK => 1) or
             die "$0: Opening include '$file': $IO::ReadPreProcess::errstr\n";                       
 
-        # All that is next should be empty lines
+        # All that is next should be empty lines:
         while (<$inc>) {
-            die "Non empty line found at $inc->{Place}\n"
+            die "Non empty line found via '--include $file' at $inc->{Place}\n"
                 if /\S/;
         }
     }
